# remirepo spec file for php-pecl-fann
# with SCL compatibility, from:
#
# Fedora spec file for php-pecl-fann
#
# Copyright (c) 2013-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-fann}

%bcond_without     tests

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  fann
%if "%{php_version}" < "5.6"
%global ini_name   %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif

%global upstream_version 1.2.0
%global upstream_prever  RC2
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Summary:        Wrapper for FANN Library
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        4%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  fann-devel > 2.1
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This package provides a PHP binding for FANN
(Fast Artificial Neural Network) Library.

Documentation: http://php.net/fann

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_FANN_VERSION/{s/.* "//;s/".*$//;p}' php_fann.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=$PWD/../ZTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{?_licensedir:%license %{sources}/LICENSE}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 1.2.0~RC2-4
- rebuild for PHP 8.3.0RC1

* Thu Jul 13 2023 Remi Collet <remi@remirepo.net> - 1.2.0~RC2-3
- build out of sources tree

* Thu Sep  8 2022 Remi Collet <remi@remirepo.net> - 1.2.0~RC2-2
- spec cleanup

* Mon Jan  3 2022 Remi Collet <remi@remirepo.net> - 1.2.0~RC2-1
- update to 1.2.0RC2
- drop patches merged upstream

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.2.0~RC1-3
- rebuild for 8.1.0RC1

* Thu Jun 10 2021 Remi Collet <remi@remirepo.net> - 1.2.0~RC1-2
- add patch for PHP 8.1 from
  https://github.com/bukka/phpc/pull/2
  https://github.com/bukka/php-fann/pull/43

* Mon Mar 15 2021 Remi Collet <remi@remirepo.net> - 1.2.0~RC1-1
- update to 1.2.0RC1
- drop all patches merged upstream

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.1.1-19
- rebuild for PHP 8.0.0RC1

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.1.1-18
- rebuild for PHP 8.0.0beta3

* Tue Aug 25 2020 Remi Collet <remi@remirepo.net> - 1.1.1-17
- add patches for PHP8 from
  https://github.com/bukka/php-fann/pull/42
  https://github.com/bukka/phpc/pull/1

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.1.1-14
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.1.1-13
- rebuild for 7.4.0beta1

* Wed Mar 13 2019 Remi Collet <remi@remirepo.net> - 1.1.1-12
- F30 build

* Tue Sep  4 2018 Remi Collet <remi@remirepo.net> - 1.1.1-10
- fix libraries load order, using patch from
  https://github.com/bukka/php-fann/pull/38

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.1.1-6
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.1.1-5
- rebuld for 7.3.0alpha4 new ABI

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.1.1-4
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.1.1-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.1.1-2
- rebuild for PHP 7.1 new API version

* Sun Jun 26 2016 Remi Collet <remi@fedoraproject.org> - 1.1.1-1
- update to 1.1.1

* Thu Mar 31 2016 Remi Collet <remi@fedoraproject.org> - 1.1.0-1
- update to 1.1.0  (stable, no change since RC2)

* Mon Mar 14 2016 Remi Collet <remi@fedoraproject.org> - 1.1.0-0.2.RC2
- update to 1.1.0RC2

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 1.1.0-0.1.RC1
- update to 1.1.0RC1

* Sat Jun 20 2015 Remi Collet <remi@fedoraproject.org> - 1.0.7-5
- allow build against rh-php56 (as more-php56)
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.0.7-4.1
- Fedora 21 SCL mass rebuild

* Mon Aug 25 2014 Remi Collet <rcollet@redhat.com> - 1.0.7-4
- improve SCL build

* Fri Aug  1 2014 Remi Collet <remi@fedoraproject.org> - 1.0.7-3
- don't install tests
- fix license handling
- add build option --without tests

* Wed Apr 16 2014 Remi Collet <remi@fedoraproject.org> - 1.0.7-2
- add numerical prefix to extension configuration file

* Wed Jan 01 2014 Remi Collet <remi@fedoraproject.org> - 1.0.7-1
- Update to 1.0.7 (stable)

* Wed Jan 01 2014 Remi Collet <remi@fedoraproject.org> - 1.0.6-1
- Update to 1.0.6 (stable)

* Fri Nov 29 2013 Remi Collet <rcollet@redhat.com> - 1.0.5-1
- adapt for SCL

* Thu Oct 17 2013 Remi Collet <remi@fedoraproject.org> - 1.0.5-1
- Update to 1.0.5
- install doc in pecl doc_dir
- install tests in pecl test_dir

* Sat Oct 12 2013 Remi Collet <remi@fedoraproject.org> - 1.0.4-1
- Update to 1.0.4 (stable)

* Mon Oct 07 2013 Remi Collet <remi@fedoraproject.org> - 1.0.3-1
- Update to 1.0.3 (stable)
- drop merged pacth

* Fri Sep 27 2013 Remi Collet <remi@fedoraproject.org> - 1.0.2-1
- initial package
- open https://github.com/bukka/php-fann/pull/5
- open https://github.com/bukka/php-fann/issues/4
